@@ -34,8 +34,9 @@ legendCodings<-function(x){
   out<-c(
     get.pCodes(x),
     get.bracketCodes(x),
-    get.HTMLcodes(x),
-  #  get.CronbachAlpha(x),
+    get.HTMLpCodes(x),
+    get.HTMLvalue(x),
+    #  get.CronbachAlpha(x),
     get.diagonal(x),
     get.abbr(x),
     get.N(x),
@@ -497,7 +498,65 @@ get.N<-function(x){
   return(list(N=n))
 }
 
-get.HTMLcodes<-function(x){
+get.HTMLvalue<-function(x){
+  boldValue<-NULL;italicValue<-NULL
+  x<-grep(" [Bb]olde*d*[^a-z]|^[Bb]olde*d*[^a-z]| [Ii]talic[^a-z]|^[Ii]talic[^a-z]",x,value=TRUE)
+  # escape
+  if(length(x)==0) return(list(boldValue=boldValue, italicValue=italicValue))
+  # split
+  x<-unlist(strsplit(x,"[,;.][ [:punct:]]"))
+  # remove lines with reference to significance and diagonal
+  x<-grep("[Ss]ignific|p *[<=>][<=>]* *0*\\.[0-9]|[Dd]iagonal",x,invert = TRUE, value = TRUE)
+  # and further lines
+  x<-grep("\\|\\.[0-9]|greater|above|under|below|[<=>]",x,invert = TRUE, value = TRUE)
+  # select only bold and italic
+  x<-grep(" [Bb]olde*d*[^a-z]|^[Bb]olde*d*[^a-z]| [Ii]talic[^a-z]|^[Ii]talic[^a-z]",x,value=TRUE)
+  # escape
+  if(length(x)==0) return(list(boldValue=boldValue, italicValue=italicValue))
+  
+  x<-JATSdecoder::letter.convert(x,greek2text=TRUE)
+  
+  fun<-function(x){
+  alpha<-NULL;omega<-NULL;AVE<-NULL;SD<-NULL;M<-NULL;accuracy<-NULL;CI<-NULL;out<-NULL;VIF<-NULL;R2<-NULL;RMSE<-NULL
+  
+  if(length(grep("Cronbach|[^A-z][aA]lpha|internal consistenc|consistency*i*e*s*",x,value=TRUE))>0)
+    alpha<-"alpha"
+  if(length(grep("[^A-z][Oo]mega",x))>0)
+    omega<-"omega"
+#  if(length(grep("[Cc]onfidence[- ][Ii]nter",x))>0)
+#    CI<-"CI"
+  if(length(grep("[- ]R\\^*2|^R\\^*2|of determination|determination.*coefficient",x))>0)
+    R2<-"R2"
+  if(length(grep("RMSE|RMSR",x))>0)
+    RMSE<-"RMSE"
+  if(length(grep("VIF|[Vv]ariance [Ii]nflation",x))>0)
+    VIF<-"VIF"
+  if(length(grep("([Aa]verage[- ][Vv]ariance[- ][Ee]x|[^A-z]AVEs*[^A-z]|[^A-z]AVEs*$)",x))>0)
+    AVE<-ifelse(length(grep("\u221a|root|[sS]quare|sqrt",
+                            grep("[Aa]verage[- ][Vv]ariance[- ][Ee]x|[^A-z]AVEs*[^A-z]|[^A-z]AVEs*$",x,value=TRUE)))>0,
+                "sqrt AVE","AVE")
+  if(length(grep("[Aa]ccuracy",x,value=TRUE))>0)
+    accuracy<-"accuracy"
+  if(length(grep("[sS]tandard [Dd]eviation",x,value=TRUE))>0)
+    SD<-"SD"
+  temp<-grep("[sS]tandard [Dd]eviation",x,value=TRUE)
+  if(length(grep("^Means*[^a-z]| [Mm]eans[^a-z]",x,value=TRUE))>0)
+    M<-"M"
+  
+  if(!is.null(c(omega,alpha,AVE,VIF,R2,RMSE,accuracy)))
+    # only take first element
+    out<-paste(c(omega,alpha,AVE,VIF,R2,RMSE,accuracy)[1],collapse=", ")
+  return(out)
+  }
+  b<-grep(" [Bb]olde*d*[^a-z]|^[Bb]olde*d*[^a-z]",x,value=TRUE)
+  i<-grep(" [Ii]talic[^a-z]|^[Ii]talic[^a-z]",x,value=TRUE)
+  boldValue<-fun(b)
+  italicValue<-fun(i)
+  
+  return(list(boldValue=boldValue, italicValue=italicValue))
+}
+
+get.HTMLpCodes<-function(x){
   boldP<-NULL;italicP<-NULL
   # select lines
   x<-grep("[Bb]old[^a-z]|[Ii]talic[^a-z]",x,value=TRUE)
@@ -551,12 +610,6 @@ get.HTMLcodes<-function(x){
   x<-gsub("(italic.*), (.*bold)","\\1SPLIT\\2",x)
   x<-unlist(strsplit(x,"SPLIT"))
     
-  #if(length(grep("[Cc]ronbach'*s* alpha|[Ii]ntern.*consist",x))>0){
-#    # and escape if has alpha
-#    if(length(grep("[Bb]old",x))>0) boldP<-"CrAlpha"
-#    if(length(grep("[Ii]talic",x))>0)  italicP<-"CrAlpha"
-#    } 
-  
   # insert p<.05 if only significant, but no number is detected
   i<-grep("p[<=>][<=>]*|[0-9]",x,invert=TRUE)
     x[i]<-gsub("[Ss]ignific[a-z]*","p<.05",x[i])
@@ -588,10 +641,12 @@ get.HTMLcodes<-function(x){
   if(length(italic)>0) italic<-italic[1]
   if(length(italicP)>0) italicP<-italicP[1]
   
-  return(list(bold=unique(c(bold,boldP)),italic=unique(c(italic,italicP))))
+  return(list(boldP=unique(c(bold,boldP)),italicP=unique(c(italic,italicP))))
   
 }
 
+
+
 ############################
 get.bracketCodes<-function(x){
   # correct sentences ends
@@ -1061,8 +1116,8 @@ ngram2<-function(x,pattern,ngram=c(-3,3),tolower=FALSE,split=FALSE,exact=FALSE){
   if(length(x)>0){
     text<-unlist(x)
     #text<-text2sentences(x)
-    if(split==TRUE) text<-unlist(strsplit(text,"[:;,.] "))
-    if(tolower==TRUE){ pattern<-tolower(pattern); text<-tolower(text)}
+    if(isTRUE(split)) text<-unlist(strsplit(text,"[:;,.] "))
+    if(isTRUE(tolower)){ pattern<-tolower(pattern); text<-tolower(text)}
     if(length(grep(pattern,text))>0){
       if(sum(!is.na(text))>0){
         # select lines
@@ -1070,8 +1125,8 @@ ngram2<-function(x,pattern,ngram=c(-3,3),tolower=FALSE,split=FALSE,exact=FALSE){
         # vectorize lines and extract ngram
         temp<-vectorize.text(text)
         # get positions of pattern in lines
-        if(exact==TRUE) ind<-lapply(lapply(temp,function(y) grep(paste0("^",pattern,"$"),y)),max,warn=F)
-        if(exact==FALSE) ind<-lapply(lapply(temp,function(y) grep(pattern,y)),max,warn=F)
+        if(isTRUE(exact)) ind<-lapply(lapply(temp,function(y) grep(paste0("^",pattern,"$"),y)),max,warn=F)
+        if(isFALSE(exact)) ind<-lapply(lapply(temp,function(y) grep(pattern,y)),max,warn=F)
         # get index of ngram in lines
         # For several pattern matchess in one line, take max of index
         ind<-lapply(ind,function(y) y+(ngram[1]:ngram[2]))
