@@ -71,7 +71,7 @@ matrix2text<-function(x,legend=NULL,
   if(length(x)==0) return(NULL)
   if(length(unlist(x))==0) return(NULL)
   
-  if(!isTRUE(decodeP)) noSign2p<-FALSE
+  if(isFALSE(decodeP)) noSign2p<-FALSE
 
   # single matrix to list
   if(is.matrix(x)) x<-list(x)
@@ -112,7 +112,7 @@ matrix2text<-function(x,legend=NULL,
   # set NA to ""
   x[is.na(x)]<-""
   # unify matrix content
-  if(unifyMatrix==TRUE) x<-unifyMatrixContent(x,correctComma=correctComma,na.rm=na.rm)
+  if(isTRUE(unifyMatrix)) x<-unifyMatrixContent(x,correctComma=correctComma,na.rm=na.rm)
   
   if(is.matrix(x)){
   # insert col and row names to inner matrix
@@ -151,16 +151,17 @@ matrix2text<-function(x,legend=NULL,
                              superscript2bracket=superscript2bracket,dfHandling=dfHandling)
 
   # unify output for better readability of get.stats
-  if(unifyMatrix==TRUE) out<-lapply(out,unifyOutput)
+  if(isTRUE(unifyMatrix)) out<-lapply(out,unifyOutput)
   
   if(length(out)==0) return(NULL)
+  
   names(out)<-names(x)
-  names(out)[1]<-"Table 1"
-  #names(out)<-paste("Pable",1:length(out))
+#  names(out)[1]<-"Table 1"
+
   if(isTRUE(unlist)){
     n<-rep(names(out),times=unlist(lapply(out,length)))
     if(isTRUE(addTableName)) out<-paste0(n,":: ",unname(unlist(out)))
-    if(!isTRUE(addTableName)) out<-unname(unlist(out))
+    if(isFALSE(addTableName)) out<-unname(unlist(out))
   }
     return(out) 
 
