@@ -59,8 +59,8 @@ parseMatrixContent<-function(x,legend=NULL,
     pval<-codesFromLegend$pval
     abbr<-codesFromLegend$abbreviation
     label<-codesFromLegend$label
-    italic<-codesFromLegend$italic
-    bold<-codesFromLegend$bold
+    italic<-codesFromLegend$italicP
+    bold<-codesFromLegend$boldP
     alpha<-codesFromLegend$alpha
     N<-codesFromLegend$N
     sup<-codesFromLegend$superscript
@@ -99,17 +99,17 @@ parseMatrixContent<-function(x,legend=NULL,
     x<-parseContent(x)
     # add degrees of freedom
     if(isTRUE(dfHandling)){
-      # add df=max(n)-2 for t and r values if has N>3 in legend
-      if(length(N)>0){
+      # add df=max(n)-2 for t and r values if has N>3 in legend and only one N
+      if(length(N)==1){
         # get highest N
         maxN<-suppressWarnings(max(suppressWarnings(as.numeric(gsub(".*[<=>]","",N))),na.rm=T))
         # add maxN-2 to r= and t= if no df is found
-        i<-(grep(" df[12]*=|degrees* of freed",x,invert=TRUE))
+        i<-(grep(" [dD]\\.*[fF]\\.*[12]* *=|degrees* of freed",x,invert=TRUE))
         maxN<-maxN[maxN>3]
         if(length(maxN)>0){
-        if(maxN!=-Inf) x[i]<-gsub(" r=",paste0(" r(",maxN-2,")="),x[i])
-        if(maxN!=-Inf) x[i]<-gsub(" t=",paste0(" t(",maxN-2,")="),x[i])
-        #if(maxN!=-Inf) x[i]<-gsub(" T=",paste0(" T(",maxN-2,")="),x[i])
+        if(maxN!=-Inf) x[i]<-gsub(" r *=",paste0(" r(",maxN-2,")="),x[i])
+        if(maxN!=-Inf) x[i]<-gsub(" t *=",paste0(" t(",maxN-2,")="),x[i])
+        #if(maxN!=-Inf) x[i]<-gsub(" T *=",paste0(" T(",maxN-2,")="),x[i])
       }}
     }
     return(x)
@@ -129,6 +129,7 @@ parseMatrixContent<-function(x,legend=NULL,
     if(length(i)>0){
       for(j in i) m[-1,j-1]<-paste0(m[-1,j-1],m[-1,j])
       m<-m[,-i]
+      if(!is.matrix(m)) m<-as.matrix(m)
     }
   }
   
@@ -158,14 +159,16 @@ parseMatrixContent<-function(x,legend=NULL,
     # add degrees of freedom
     if(isTRUE(dfHandling)){
       # add df=max(n)-2 for t and r values if has N= in legend
-      if(!is.null(N)){
+      if(length(N)==1&sum(grepl("[\\( ][nN]=|^[nN]=",m))==0 &
+         # and no df in matrix
+         sum(grepl("^[Dd]\\.*[Ff]\\.*$|degrees* of freedom",m))==0){
         # get highest N
         maxN<-suppressWarnings(max(suppressWarnings(as.numeric(gsub(".*[<=>]","",N))),na.rm=T))
         # add maxN-2 to r= and t= if no df is found
         i<-(grep(" df[12]*=|degrees* of freed",m,invert=TRUE))
-        if(maxN!=-Inf) m[i]<-gsub(" r=",paste0(" r(",maxN-2,")="),m[i])
-        if(maxN!=-Inf) m[i]<-gsub(" t=",paste0(" t(",maxN-2,")="),m[i])
-        if(maxN!=-Inf) m[i]<-gsub(" T=",paste0(" T(",maxN-2,")="),m[i])
+        if(maxN!=-Inf) m[i]<-gsub(" r *=",paste0(" r(",maxN-2,")="),m[i])
+        if(maxN!=-Inf) m[i]<-gsub(" t *=",paste0(" t(",maxN-2,")="),m[i])
+        #if(maxN!=-Inf) m[i]<-gsub(" T *=",paste0(" T(",maxN-2,")="),m[i])
       }
     }
     return(m) 
@@ -214,11 +217,13 @@ parseMatrixContent<-function(x,legend=NULL,
     if(length(grep("[A-z]",m[-1,1]))==0&length(grep("^[A-z]",m[-1,2]))==(nrow(m)-1)){
       m[,1]<-paste(m[,1],m[,2])
       m<-m[,-2]
+      if(!is.matrix(m)) m<-as.matrix(m)
     }
     # parse first and second row, if first row has no letters and second row starts with letter in every cell
     if(length(grep("[A-z]",m[1,-1]))==0&length(grep("^[A-z]",m[2,-1]))==(ncol(m)-1)){
       m[1,]<-paste(m[1,],m[2,])
       m<-m[-2,]
+      if(!is.matrix(m)) m<-as.matrix(m)
     }
   }
   
@@ -226,14 +231,14 @@ parseMatrixContent<-function(x,legend=NULL,
   
   # convert numbers in brackets in inner matrix
   if(isTRUE(bracketHandling)){
-  if(length(parentheses)>0) m[-1,-1]<-bracket2value(m[-1,-1],parentheses,"parentheses",sep=";;")
-  if(length(brackets)>0) m[-1,-1]<-bracket2value(m[-1,-1],brackets,"brackets",sep=";;")
-  if(length(brackets)>0&length(parentheses)==0) m[-1,-1]<-bracket2value(m[-1,-1],brackets,"parentheses",sep=";;")
-  if(length(brackets)==0&length(parentheses)>0) m[-1,-1]<-bracket2value(m[-1,-1],brackets,"brackets",sep=";;")
+  if(length(parentheses)>0) m[-1,-1]<-bracket2value(m[-1,-1],parentheses,"parentheses",sep=",")
+  if(length(brackets)>0) m[-1,-1]<-bracket2value(m[-1,-1],brackets,"brackets",sep=",")
+  if(length(brackets)>0&length(parentheses)==0) m[-1,-1]<-bracket2value(m[-1,-1],brackets,"parentheses",sep=",")
+  if(length(brackets)==0&length(parentheses)>0) m[-1,-1]<-bracket2value(m[-1,-1],brackets,"brackets",sep=",")
   }
   
   # add standard p-coding
-  if(standardPcoding==TRUE&length(pval)==0){
+  if(isTRUE(standardPcoding)&length(pval)==0){
     psign<-c("***","**","*")
     pval<-c("p<.001","p<.01","p<.05")
   }
@@ -301,14 +306,16 @@ parseMatrixContent<-function(x,legend=NULL,
     # add degrees of freedom
     if(isTRUE(dfHandling)){
       # add df=max(n)-2 for t and r values if has N= in legend
-      if(!is.null(N)){
+      if(length(N)==1& 
+         # and no df in matrix
+         sum(grepl("^[Dd]\\.*[Ff]\\.*$|degrees* of freedom|df1|df2",m))==0){
         # get highest N
         maxN<-suppressWarnings(max(suppressWarnings(as.numeric(gsub(".*[<=>]","",N))),na.rm=T))
         # add maxN-2 to r= and t= if no df is found
         i<-(grep(" df[12]*=|degrees* of freed",m,invert=TRUE))
-        if(maxN!=-Inf) m[i]<-gsub(" r=",paste0(" r(",maxN-2,")="),m[i])
-        if(maxN!=-Inf) m[i]<-gsub(" t=",paste0(" t(",maxN-2,")="),m[i])
-        if(maxN!=-Inf) m[i]<-gsub(" T=",paste0(" T(",maxN-2,")="),m[i])
+        if(maxN!=-Inf) m[i]<-gsub(" r *=",paste0(" r(",maxN-2,")="),m[i])
+        if(maxN!=-Inf) m[i]<-gsub(" t *=",paste0(" t(",maxN-2,")="),m[i])
+        #if(maxN!=-Inf) m[i]<-gsub(" T *=",paste0(" T(",maxN-2,")="),m[i])
       }
     }
     return(m)
@@ -328,6 +335,7 @@ parseMatrixContent<-function(x,legend=NULL,
     m[2,][m[1,]==m[2,]]<-""
     m[1,]<-gsub("^  *|  *$","",paste(m[1,],m[2,]))
     m<-m[-2,]
+    if(!is.matrix(m)) m<-as.matrix(m)
   }
 
   ###################################################################
@@ -355,12 +363,14 @@ parseMatrixContent<-function(x,legend=NULL,
     # add df to extracted correlations
     if(class=="correlation")
       if(isTRUE(dfHandling)){
-      # add df=max(n)-2 if has N in legend
-      if(!is.null(N)){
+      # add df=max(n)-2 if has N in legend and no n= in matrix
+      if(length(N)==1 & sum(grepl("[\\( ][nN]=|^[nN]=",m))==0 &
+         # and no df in matrix
+         sum(grepl("^[Dd]\\.*[Ff]\\.*$|degrees* of freedom|df1|df2",m))==0){
       # get highest N
       maxN<-suppressWarnings(max(suppressWarnings(as.numeric(gsub(".*[<=>]","",N))),na.rm=T))
       # add maxN-2 to r=
-      if(maxN!=-Inf) correlations<-gsub("r=",paste0("r(",maxN-2,")="),correlations)
+      if(maxN!=-Inf) correlations<-gsub("r *=",paste0("r(",maxN-2,")="),correlations)
     }
   }
 } # results are in updated "m" and object "correlations"
@@ -378,8 +388,10 @@ parseMatrixContent<-function(x,legend=NULL,
   i<-NULL;j<-NULL
   if(length(m)>0&is.matrix(m)){
   # convert ns -> p>.05
-  if(standardPcoding==TRUE) m<-gsub(" [Nn]\\.*[Ss]\\.*$",";; p>.05",m)
-  if(standardPcoding==TRUE) m<-gsub("^[Nn]\\.*[Ss]\\.*$",";; p>.05",m)
+  if(isTRUE(standardPcoding)){
+    m<-gsub(" [Nn]\\.*[Ss]\\.*$",";; p>.05",m)
+    m<-gsub("^[Nn]\\.*[Ss]\\.*$",";; p>.05",m)
+  }
   
   # add non significant p-values in columns that have cells with coded p-values,
   if(isTRUE(noSign2p)){
@@ -396,6 +408,7 @@ parseMatrixContent<-function(x,legend=NULL,
   if(length(j)>0) m[j,]<-t(noSign2p(t(as.matrix(m[c(1,j),])),pval))[-1,]
   # remove inserted grouping from Model stats
   m[-i,1]<-gsub("^[^,;]*: ","",m[-i,1])
+  if(!is.matrix(m)) m<-as.matrix(m)
   }
 }  
   # which line has number-star in model stats
@@ -432,34 +445,33 @@ parseMatrixContent<-function(x,legend=NULL,
   firstCell<-"Variable"
   output<-gsub(paste0("^(",specialChars(firstCell),": [^:]*: )",specialChars(firstCell),": "),"\\1",output)
   
-  # convert abbreviations in first row and col
-  #output<-abb2text(output,abbr=abbr,label=label)
-  
-  # escape if no stats are detected
+  # escape if nothing left
   if(length(output)==0) return(NULL)
+  
   # remove "[:;=,] " at start
   output<-gsub("^ *[:;=,] *","",output)
   # remove second sign
   output<-gsub(", [:;=,] *",", ",output)
   output<-gsub("  *"," ",output)
   
-  #output<-unifyStats(output)
   
   # add degrees of freedom
   if(isTRUE(dfHandling)){
-    # add df=max(n)-2 for t and r values if has N= in legend
-    if(!is.null(N)){
+    # add df=max(n)-2 for t and r values if has N= in legend but not in matrix
+    if(length(N)==1 & sum(grepl("[\\( ][nN] *= *[1-9]|^[nN] *= *[1-9]",m))==0 &
+       # and no df in matrix
+       sum(grepl("^[Dd]\\.*[Ff]\\.*$|degrees* of freedom|df1|df2",m))==0){
       # get highest N
       maxN<-suppressWarnings(max(suppressWarnings(as.numeric(gsub(".*[<=>]","",N))),na.rm=T))
       # add maxN-2 to r= and t= if no df is found
-      i<-(grep(" df[12]*=|degrees* of freed",output,invert=TRUE))
-      if(maxN!=-Inf) output[i]<-gsub(" r=",paste0(" r(",maxN-2,")="),output[i])
-      if(maxN!=-Inf) output[i]<-gsub(" t=",paste0(" t(",maxN-2,")="),output[i])
-      if(maxN!=-Inf) output[i]<-gsub(" T=",paste0(" T(",maxN-2,")="),output[i])
+      i<-(grep(" [dD][fF][12]* *=|degrees* of freed",output,invert=TRUE))
+      if(maxN!=-Inf) output[i]<-gsub(" r *=",paste0(" r(",maxN-2,")="),output[i])
+      if(maxN!=-Inf) output[i]<-gsub(" t *=",paste0(" t(",maxN-2,")="),output[i])
+#      if(maxN!=-Inf) output[i]<-gsub(" T *=",paste0(" T(",maxN-2,")="),output[i])
     }
     # perform ANOVQA df handling
     output<-anovaHandler(output)  
-    
+    output<-correctDF(output)
   }
   
   # clean up spaces
@@ -467,11 +479,11 @@ parseMatrixContent<-function(x,legend=NULL,
   # remove ": ;;"
   output<-gsub(": ;;",";;",output)
   
-  # remove more than one appearing of grouping variable
+  # remove more than one appearing of grouping variable, if has less than 100 characters
   group<-gsub("^([^:][^:]*): .*","\\1",output)
-  ind<-which(group!=output)
+  ind<-which(group!=output & nchar(group)<100)
   if(length(ind)>0)
-  for(i in ind) output[i]<-gsub(paste0(" ",specialChars(group[i]),": ")," ",output[i])
+     for(i in ind) output[i]<-gsub(paste0(" ",specialChars(group[i]),": ")," ",output[i])
 
   # clean up spaces
   output<-gsub("  *"," ",output)
