@@ -53,7 +53,7 @@ prepareMatrix<-function(x,split=FALSE,forceClass=NULL,na.rm=TRUE,legend=NULL){
     }
   }
   
-  
+  x
   # remove empty lines/cols
   row.rm<-which(rowSums(x=="",na.rm=TRUE)==ncol(x))
   if(length(row.rm)>0) x<-x[-row.rm,]
@@ -87,6 +87,7 @@ prepareMatrix<-function(x,split=FALSE,forceClass=NULL,na.rm=TRUE,legend=NULL){
     i<-i[i>min(j)]
   }
   }
+  
   # paste text from lines with only the same value to first cells
   x<-multiHeaderSplit(x,split=FALSE,class=class)
   # handle empty cells by row (except for correlations)
@@ -98,17 +99,20 @@ prepareMatrix<-function(x,split=FALSE,forceClass=NULL,na.rm=TRUE,legend=NULL){
   
   ## if second column contains enumerated text 
   # paste first and second col -> "col2 (col1)"
-  if(isTRUE(
-    grep("^\\(1\\)|^1\\.[A-z ]",x[-1,2])[1]==grep("^\\(2\\)|^2\\.[A-z ]",x[-1,2])[1]-1&
-    grep("^\\(1\\)|^1\\.[A-z ]",x[-1,2])[1]==grep("^\\(3\\)|^3\\.[A-z ]",x[-1,2])[1]-2)){
+  if(ncol(x)>1 & isTRUE(
+    grep("^\\(1\\)|^1\\. *[A-z]",x[-1,2])[1]==grep("^\\(2\\)|^2\\. *[A-z]",x[-1,2])[1]-1&
+    grep("^\\(1\\)|^1\\. *[A-z]",x[-1,2])[1]==grep("^\\(3\\)|^3\\. *[A-z]",x[-1,2])[1]-2)){
     x[,2]<-paste0(x[,2],rep(" (",length(x[,1])),x[,1],rep(")",length(x[,1])))
     # remove first column
     x<-x[,-1]
     # remove empty brackets and space 
     x<-gsub(" *\\(\\)|^  *","",x)
+    if(!is.matrix(x)) x<-as.matrix(x)
+    
   }
+  
   # paste first and second col -> "col2 (col1)"
-  if(isTRUE(
+  if(ncol(x)>1 & isTRUE(
     grep("^1[\\.]*$",x[-1,2])[1]==grep("^2[\\.]*$",x[-1,2])[1]-1&
     grep("^1[\\.]*$",x[-1,2])[1]==grep("31[\\.]*$",x[-1,2])[1]-2)){
     x[,2]<-paste0(x[,2],rep(" ",length(x[,1])),x[,1])
@@ -116,6 +120,7 @@ prepareMatrix<-function(x,split=FALSE,forceClass=NULL,na.rm=TRUE,legend=NULL){
     x<-x[,-1]
     # remove space 
     x<-gsub("^  *","",x)
+    if(!is.matrix(x)) x<-as.matrix(x)
   }
   
   # reclassify if forceClass is null
@@ -148,8 +153,8 @@ prepareMatrix<-function(x,split=FALSE,forceClass=NULL,na.rm=TRUE,legend=NULL){
 
   # as long as multiple fields in second row contain only text, paste to cells in first row and remove row
   while(
-    sum(grepl("[0-9]",gsub("[1-9][0-9\\.][- ]*%","",x[2,]))) == 0 & 
-    sum(grepl("[A-z]",x[2,])) > 1 & 
+    sum(grepl("[0-9]",gsub("[0-9][0-9\\.\\^][- ]*%","",x[2,]))) == 0 & 
+    sum(grepl("[A-z]",gsub("*[Nn]\\.[Ss]\\.|^ns$","",x[2,]))) > 1 & 
     nrow(x) > 2 & 
     # no line with only the same values
     sum(duplicated(x[2,]))!= ncol(x) & 
@@ -161,7 +166,6 @@ prepareMatrix<-function(x,split=FALSE,forceClass=NULL,na.rm=TRUE,legend=NULL){
     x<-x[-2,]
   }
 
-
   # split matrices
   if(isTRUE(split)){
     # split at columns for enumerated multi models
