@@ -55,7 +55,7 @@ table2text<-function(x,
                      bracketHandling=TRUE,
                      dfHandling=FALSE,
                      rotate=FALSE,
-                     correctComma=TRUE,
+                     correctComma=FALSE,
                      na.rm=TRUE,
                      addDescription=TRUE,
                      unlist=FALSE,
@@ -69,6 +69,10 @@ table2text<-function(x,
   caption<-NULL;footer<-NULL;legend<-NULL;m<-NULL;file<-FALSE
   # extract matrices and legend (caption and footnotes)
   m<-table2matrix(x,rm.html = TRUE,unifyMatrix = unifyMatrix)
+  
+  # split matrices at text lines (if is not vector, text, correlation)
+  m<-matrixSplit(m)
+  
   # get attributes
   caption<-unname(lapply(m,function(x) attributes(x)$caption))
   caption<-unlist(lapply(caption,paste,collapse=" "))
@@ -88,7 +92,7 @@ table2text<-function(x,
                 legend=NULL,unlist=FALSE){
     
     if(length(x)==0)  return(NULL)
-    if(unifyMatrix==TRUE) x<-unifyMatrixContent(x,correctComma=correctComma,na.rm=na.rm)
+    if(isTRUE(unifyMatrix)) x<-unifyMatrixContent(x,correctComma=correctComma,na.rm=na.rm)
     if(length(x)==0) return(NULL)
     
     # convert matrix to text
@@ -111,6 +115,7 @@ table2text<-function(x,
   # escape
   if(length(m)==0) return(NULL)
   output<-list()
+  o_name<-names(m)
   # apply function
   uniqueWarnings({
   for(i in 1:length(m)) 
@@ -135,21 +140,48 @@ table2text<-function(x,
                        output[[i]]),invert=TRUE,value=TRUE)
       
   # set attributes
-  if(length(caption)==length(output) & !isTRUE(addDescription)){
+  if(length(caption)==length(output) & isFALSE(addDescription)){
     for(i in 1:length(m)){
       attributes(output[[i]])$caption <- caption[i]
       attributes(output[[i]])$footer <- footer[i]
     }
   }
   
-  # name the listed output
-  names(output)<-paste("Table",1:length(output))
+  # rename the listed output
+#  names(output)<-paste("Table",1:length(output))
+  names(output)<-o_name
   
+  # paste contentent from splitted matrices
+  x<-output
+  stop<-FALSE
+  n<-names(x)
+  while(length(grep("[0-9]\\.a",n))>0|isTRUE(stop)){
+    # in 
+    i<-grep("[0-9]\\.a",n)[1]
+    # out
+    o<-grep("[0-9]\\.a|[0-9]$",n)
+    o<-o[o>i][1]-1
+    if(is.na(o)) o<-length(n)
+    if(isTRUE(o>i)){
+      x[[i]]<-unname(unlist(x[i:o]))
+      # remove caption/footer duplicates
+      temp<-grep("^caption:|^footer:",x[[i]])
+      temp<-temp[temp>2]
+      x[[i]]<-x[[i]][-temp]
+      # rename
+      names(x)[i]<-gsub("\\.[a-z][a-z]*","",names(x)[i])
+      # remove elements
+      x<-x[(-(i+1)):(-o)]
+      n<-names(x)
+    }else stop<-TRUE
+  }
+  
+  output<-x  
   # unlist with table names
   if(isTRUE(unlist)){
     n<-rep(names(output),times=unlist(lapply(output,length)))
     if(isTRUE(addTableName)) output<-paste0(n,":: ",unname(unlist(output)))
-    if(!isTRUE(addTableName)) output<-unname(unlist(output))
+    if(isFALSE(addTableName)) output<-unname(unlist(output))
   }  
   return(output)
   }
