@@ -5,7 +5,7 @@
 #' @param letter.convert Logical. If TRUE, hexadecimal- and html-encoded letters will be unified and converted to Unicode with JATSdecoder::letter.convert().
 #' @param greek2text Logical. If TRUE and 'letter.convert=TRUE', converts and unifies various Greek letters to a text-based form (e.g., 'alpha', 'beta'). 
 #' @param text2num Logical. If TRUE, textual representations of numbers (words, exponents, fractions) are converted to digit numbers. 
-#' @param correctComma Logical. If TRUE, commas used as numeric separators are converted to dots. 
+#' @param correctComma Logical. If TRUE, commas used as decimal are converted to dots, big mark commas are removed. 
 #' @param na.rm Logical. If TRUE, cells with NA, or only minus, hyphen, slash, or dot are set to empty cells.
 #' @returns A unified character matrix or list of character matrices.
 #' @examples
@@ -79,17 +79,18 @@ unifyMatrixContent<-function(x,letter.convert=TRUE,
     x<-gsub("^(-*) *\\. *([0-9])","\\1.\\2",x)
     
     # if has potential big mark Comma remove it
+    if(isTRUE(correctComma)){
     patBM<-"[0-9],[0-9]{3}$|[0-9],[0-9]{3}[^0-9]"
     if(length(grep(patBM,x))>0){
       # except df in F-values
       patDF<-"^F[ _]*\\([1-9][\\.0-9]*,[1-9][\\.0-9,]*\\)|[- ]F[_ ]*\\([1-9][\\.0-9]*,[1-9][\\.0-9,]*\\)"
       i<-grep(patDF,x,invert=TRUE)
       if(length(i)>0){
-        warning("One or more detected big mark comma signs were removed from numeric content.",call.=FALSE)
+        warning("One or more detected big mark commas were removed from big numbers (e.g. '10,000' -> '10000').",call.=FALSE)
         x[i]<-gsub("([0-9]),([0-9]{3})","\\1\\2",x[i])
       }
     }
-    
+    }
     ## comma to dot correction
     # in "F(num, num,3num)" -> "F(num, num.3num)"
     if(isTRUE(correctComma)){
@@ -110,7 +111,6 @@ unifyMatrixContent<-function(x,letter.convert=TRUE,
       }
     }
     
-    
     # has Comma as decimal (obviously cases: 1,2,4 or more decimals, 0,number)
     patComma<-"[0-9],[0-9][^0-9]|[0-9],[0-9]$|[0-9],[0-9]{2}[^0-9]|[0-9],[0-9]{2}$|[0-9],[0-9][0-9][0-9][0-9][^0-9][0-9]*|[0-9],[0-9][0-9][0-9][0-9][0-9]*$|^[^0-9]*0*,[0-9]{3}|[^0-9,]0*,[0-9]{3}$"
     # has dot as decimal (obviously cases: 1,2,4 or more decimals, 0,number)
@@ -129,7 +129,7 @@ unifyMatrixContent<-function(x,letter.convert=TRUE,
     if(length(grep(patComma,grep(patF,x,invert=TRUE,value=TRUE)))>0&length(grep(patDot,x))>0){
       warning(paste0(paste0("There is an inconsistent use of decimal signs. Found for numeric value/s: '",
                      paste(grep(patComma,grep(patF,x,invert=TRUE,value=TRUE),value=TRUE),collapse="; ")),
-      ifelse(!isTRUE(correctComma), "'\nYou may consider to set the argument correctComma=TRUE to unify the decimal sign to dots.","")),call.=FALSE)
+      ifelse(isFALSE(correctComma), "'\nYou may consider to set the argument correctComma=TRUE to unify the decimal sign to dots.","")),call.=FALSE)
     }
 
     # x as vector
@@ -173,12 +173,12 @@ unifyMatrixContent<-function(x,letter.convert=TRUE,
     x<-gsub(":$","",x)
     
     # remove space around operator number
-    x<-gsub("([A-z2]) *([<=>][<=>]*) *(-*[0-9\\.-])","\\1\\2\\3",x)
+    x<-gsub("([A-z2\\(\\[]) *([<=>][<=>]*) *(-*[0-9\\.-])","\\1\\2\\3",x)
     # remove space between operator number at start
     x<-gsub("^ *([<=>][<=>]*) *(-*[0-9\\.-])","\\1\\2",x)
     # add Comma between number/star-letter-operator
     x<-gsub("([0-9\\*])( [A-z][A-z]*[<=>][<=>]*[-0-9\\.])","\\1,\\2",x)
-    if(letter.convert==TRUE) {
+    if(isTRUE(letter.convert)) {
       x<-html2unicode(x)
       x<-JATSdecoder::letter.convert(x,greek2text=greek2text)
       }
