@@ -32,8 +32,8 @@ unifyStats<-function(x,dfHandling=FALSE){
   x<-gsub("\u00DF|\u03b2","b",x)
   # text to number
   x<-text2num(x,percentage=FALSE,words=FALSE)
-  # clean up white space around operator
-  x<-gsub(" *([<=>][<=>]*) *","\\1",x)        
+  # clean up white space around operator-number
+  x<-gsub(" *([<=>][<=>]*) *(-*[\\.0-9])","\\1\\2",x)        
   # add space in "num.num,num.num" -> "num.num, num.num"
   x<-gsub("([0-9]\\.[0-9][0-9]*),([0-9][0-9]*\\.[0-9])","\\1, \\2",x)
   # correct ", =letter"
@@ -60,7 +60,8 @@ unifyStats<-function(x,dfHandling=FALSE){
   # clean up comma
   x<-gsub(",,",",",x)
   x<-gsub(", *$","",x)
-  
+  # semicolon to comma
+  x<-gsub("([0-9]); ([^0-9\\.])","\\1, \\2",x)
   # unify CI: [num, num]    
   x<-gsub("[cC]onfidence [iI]ntervall*s*|[Cc]onf\\.*[ -][Ii]nt\\.*e*r*v*a*l*","CI",x)
   x<-gsub("(\\.*[1-9][0-9]\\%*)[ -]*C\\.*I\\.*[:=]","\\1 CI:",x)
@@ -110,8 +111,8 @@ unifyStats<-function(x,dfHandling=FALSE){
   # remove "statistic"/"value
   x<-gsub("[- ][Ss]tatistics*([<=>])","\\1",x)
   x<-gsub("[- ][Vv]alues*([<=>])","\\1",x)
-  # and other text behind "-"
-  x<-gsub("([A-z]) *- *[A-z]*([<=>])","\\1\\2",x)
+  # and other text behind "-" in front of result
+  x<-gsub("([A-z]) *- *[A-z]*([<=>][<=>]*-*[\\.0-9])","\\1\\2",x)
   
   # degrees of freedom
   x<-gsub("[dD][fF]1, *[dD][fF]2","df1, df2",x)
@@ -184,9 +185,9 @@ unifyStats<-function(x,dfHandling=FALSE){
   # OR/RR-anything to anything-OR/RR
   x<-gsub("(R\\^2)[-_ ]([-a-zA-z \\.]*)([<=>])"," \\2 \\1\\3",x)
   
-  # add "d=" to effect in lines with SE
-  x<-gsub("( [Ee]ffects*)([<=>][<=>]*-*[\\.0-9][\\.0-9]*[,;]*[^<=>]* \\(*SE[<=>][<=>]*[\\.0-9])"," \\1 d\\2",x)
-  x<-gsub("( [Ee]ffects*)([<=>][<=>]*-*[\\.0-9][\\.0-9]*[,;]*[^<=>]* p[<=>][<=>]*[0-9\\.][0-9\\.]*[,;]*[^<=>]* SE[<=>][<=>]*[\\.0-9])"," \\1 d\\2",x)
+  # add "b=" to effect in lines with SE
+  x<-gsub("( [Ee]ffects*)([<=>][<=>]*-*[\\.0-9][\\.0-9]*[,;]*[^<=>]* \\(*SE[<=>][<=>]*[\\.0-9])"," \\1 b\\2",x)
+  x<-gsub("( [Ee]ffects*)([<=>][<=>]*-*[\\.0-9][\\.0-9]*[,;]*[^<=>]* p[<=>][<=>]*[0-9\\.][0-9\\.]*[,;]*[^<=>]* SE[<=>][<=>]*[\\.0-9])"," \\1 b\\2",x)
   
   # remove badly set space in "=. num"
   x<-gsub("([<=>]\\.) ([0-9])","\\1\\2",x)
@@ -210,7 +211,7 @@ unifyStats<-function(x,dfHandling=FALSE){
   x<-gsub("  *"," ",x)
   x<-gsub("^ | $","",x)
   #  remove space before/after operator 
-  x<-gsub(" *([<>=][<>=]*) *","\\1",x)
+  x<-gsub(" *([<>=][<>=]*) *(-*[\\.0-9])","\\1\\2",x)
   # enter comma if missing between results
   x<-gsub("([<=>][<=>]*[-\\.0-9][\\.0-9]*) ([a-zA-Z0-9]*[<=>][<=>]*[-\\.0-9][\\.0-9]*)","\\1, \\2",x)
   
@@ -221,16 +222,25 @@ unifyStats<-function(x,dfHandling=FALSE){
   x
   
   ## if has line with constant/intercept/model
-  if(length(grep("[Cc]onstant|[Ii]ntercept| [Mm]odel[^a-z]|[ -]R\\^*2|^R\\^*2|AIC|BIC|nformation [Cc]riter",x))>0){
+  if(length(grep("[Cc]onstant|[Ii]ntercept| [Mm]odel[^a-z]|[ -]R\\^*2|^R\\^*2|AIC|BIC|nformation [Cc]riter|[GN ]LM[^A-z]",x))>0){
   ## add b= in lines with SE= but without b= nor d=
   i<-grepl(" SE[<=>]",x) & !grepl(" d\\|*[<=>]| [bB][<=>]| [bB]eta[<=>]",x)
     # if no potential other standard stat is in front of SE 
-    x[i]<-gsub("([a-z][a-z0-9]*[a-z])([<=>][<=>]*-*[\\.0-9][0-9\\.]*([;,];* p[<=>][<=>]*[0-9\\.][0-9\\.]*)*[,;];*[^,<=>]* [Ss][Ee]=)","\\1 b\\2",x[i])
-    x[i]<-gsub("([a-z][a-z][a-z]* [0-9]*)([<=>][<=>]*[-\\.0-9]*[0-9]([;,];* p[<=>][<=>]*[0-9\\.][0-9\\.]*)*[,;];*[^,<=>]* [Ss][Ee]=)","\\1 b\\2",x[i])
-    x[i]<-gsub("([a-z][a-z][a-z]* [0-9][-A-z_0-9]*)([<=>][<=>]*[-\\.0-9]*[0-9]([;,];* p[<=>][<=>]*[0-9\\.][0-9\\.]*)*[,;];*[^,<=>]* [Ss][Ee]=)","\\1 b\\2",x[i])
+    x[i]<-gsub("([a-z][a-z0-9]*[a-z])([<=>][<=>]*-*[\\.0-9][0-9\\.]*([;,];* p[<=>][<=>]*[0-9\\.][0-9\\.]*)*[,;];*[^,<=>]* [Ss][Ee][<=>])","\\1 b\\2",x[i])
+    x[i]<-gsub("([a-z][a-z][a-z]*[_ ][0-9]*)([<=>][<=>]*-*[\\.0-9]*[0-9]([;,];* p[<=>][<=>]*[0-9\\.][0-9\\.]*)*[,;];*[^,<=>]* [Ss][Ee][<=>])","\\1 b\\2",x[i])
+    x[i]<-gsub("([A-Z][A-Z][A-Z]*[_ ][0-9]*)([<=>][<=>]*-*[\\.0-9]*[0-9]([;,];* p[<=>][<=>]*[0-9\\.][0-9\\.]*)*[,;];*[^,<=>]* [Ss][Ee][<=>])","\\1 b\\2",x[i])
+    x[i]<-gsub("([a-z][a-z][a-z]*[_ ][0-9][-A-z_0-9]*)([<=>][<=>]*-*[\\.0-9]*[0-9]([;,];* p[<=>][<=>]*[0-9\\.][0-9\\.]*)*[,;];*[^,<=>]* [Ss][Ee][<=>])","\\1 b\\2",x[i])
   }
   
-  # CI=num, CI=num -> CI[num; num]
+  ## add b= in lines with SE= and Model num=
+  i<-grepl(" SE[<=>]",x) & grepl("^G*LM *[0-9]*[<=>]| G*LM *[0-9]*[<=>]|[Mm]odel *[0-9]*[<=>]",x)
+  # if no potential other standard stat is in front of SE 
+  x[i]<-gsub("([a-z][a-z0-9]*[a-z])([<=>][<=>]*-*[\\.0-9][0-9\\.]*([;,];* p[<=>][<=>]*[0-9\\.][0-9\\.]*)*[,;];*[^,<=>]* [Ss][Ee][<=>])","\\1 b\\2",x[i])
+  x[i]<-gsub("([a-z][a-z][a-z]*[_ ][0-9]*)([<=>][<=>]*-*[\\.0-9]*[0-9]([;,];* p[<=>][<=>]*[0-9\\.][0-9\\.]*)*[,;];*[^,<=>]* [Ss][Ee][<=>])","\\1 b\\2",x[i])
+  x[i]<-gsub("([A-Z][A-Z][A-Z]*[_ ][0-9]*)([<=>][<=>]*-*[\\.0-9]*[0-9]([;,];* p[<=>][<=>]*[0-9\\.][0-9\\.]*)*[,;];*[^,<=>]* [Ss][Ee][<=>])","\\1 b\\2",x[i])
+  x[i]<-gsub("([a-z][a-z][a-z]*[_ ][0-9][-A-z_0-9]*)([<=>][<=>]*-*[\\.0-9]*[0-9]([;,];* p[<=>][<=>]*[0-9\\.][0-9\\.]*)*[,;];*[^,<=>]* [Ss][Ee][<=>])","\\1 b\\2",x[i])
+
+# CI=num, CI=num -> CI[num; num]
   x<-gsub("([^A-Z]CI)=(-*[\\.0-9][\\.0-9]*),[^,]*CI=(-*[\\.0-9][\\.0-9]*)","\\1: [\\2; \\3]",x)
   x<-gsub("([^A-Z]CI)[ Llower]*[LimtB]*=(-*[\\.0-9][\\.0-9]*),[^,]*CI[ Uuper]*[LimtB]*=(-*[\\.0-9][\\.0-9]*)","\\1: [\\2; \\3]",x)
   x<-gsub("([^A-Z]CI)[ Llower]*[LimtB]*=(-*[\\.0-9][\\.0-9]*),[^,]*[Uu][Ll]=(-*[\\.0-9][\\.0-9]*)","\\1: [\\2; \\3]",x)
@@ -269,19 +279,27 @@ unifyStats<-function(x,dfHandling=FALSE){
   # special processing of ANOVA results (add df2 to df1)
   if(isTRUE(dfHandling)) {
     x<-anovaHandler(x)
-    # extract N and add as df to [rt]=num -> [rt](N-2)=num
+    
+    # extract N and add/replace as df to [rt]=num -> [rt](N-2)=num but no df=num by row
     funDF<-function(x){
-      if(length(grep(" [rt][<=>][<=>]*-*[\\.0-9]",x))>0){
-        if(length(grep(" [rt][<=>][<=>]*-*[\\.0-9][\\.0-9]*,.* [Nn]=([1-9][0-9]*)",x))>0){
-          N<-suppressWarnings(as.numeric(gsub(".* [rt][<=>][<=>]*-*[\\.0-9][\\.0-9]*,.* [Nn]=([1-9][0-9]*).*","\\1",x)))
-          if(!is.na(N)) x<-gsub("(.* [rt])([<=>][<=>]*-*[\\.0-9][\\.0-9]*,.* [Nn]=[1-9][0-9]*.*)",paste0("\\1(",N-2,")\\2"),x)
+      # escape if has df=num
+      if(length(grep(" [dD]\\.*[fF]\\.* *= *[1-9]|^[dD]\\.*[fF]\\.$",x))>0) return(x)
+      
+      if(length(grep(" [rt][<=>][<=>]*-*[\\.0-9]|^[rt][<=>][<=>]*-*[\\.0-9]",x))>0){
+        if(length(grep("[rt][<=>][<=>]*-*[\\.0-9][\\.0-9]*,.* [Nn]=([1-9][0-9]*)",x))>0){
+          N<-suppressWarnings(as.numeric(gsub(".*[rt][<=>][<=>]*-*[\\.0-9][\\.0-9]*,.* [Nn]=([1-9][0-9]*).*","\\1",x)))
+          if(!is.na(N)) x<-gsub("(.* [rt])([<=>][<=>]*-*[\\.0-9][\\.0-9]*,*.* [Nn]=[1-9][0-9]*.*)",paste0("\\1(",N-2,")\\2"),x)
+          if(!is.na(N)) x<-gsub("^([rt])([<=>][<=>]*-*[\\.0-9][\\.0-9]*,*.* [Nn]=[1-9][0-9]*.*)",paste0("\\1(",N-2,")\\2"),x)
         }
         
-        if(length(grep("[ \\(][Nn]=[1-9][0-9]*.* [rt][<=>][<=>]*-*[\\.0-9][\\.0-9]*",x))>0){
-          N<-suppressWarnings(as.numeric(gsub(".*[ \\(][Nn]=([1-9][0-9]*).* [rt][<=>][<=>]*-*[\\.0-9].*","\\1",x)))
+        if(length(grep("[ \\(][Nn]=[1-9][0-9]*.* [rt][<=>][<=>]*-*[\\.0-9][\\.0-9]*|^[Nn]=[1-9][0-9]*.* [rt][<=>][<=>]*-*[\\.0-9][\\.0-9]*",x))>0){
+          N<-suppressWarnings(as.numeric(gsub(".*[Nn]=([1-9][0-9]*).* [rt][<=>][<=>]*-*[\\.0-9].*","\\1",x)))
           if(!is.na(N)) x<-gsub("(.*[ \\(][Nn]=[1-9][0-9]*.* [rt])([<=>][<=>]*-*[\\.0-9])",paste0("\\1(",N-2,")\\2"),x)
+          if(!is.na(N)) x<-gsub("^([Nn]=[1-9][0-9]*.* [rt])([<=>][<=>]*-*[\\.0-9])",paste0("\\1(",N-2,")\\2"),x)
         }
       }
+      
+      
       return(x)
     }
     x<-unlist(lapply(x,funDF))
